@@ -380,7 +380,7 @@ extractAIC.trls <- function (fit, scale, k = 2, ...)
     if (!inherits(fit, "trls"))
         stop("'object' is not a fitted trend surface")
     n <- length(fit$z)
-    edf <- df.residual.trls(fit)
+    edf <- length(fit$beta)
     RSS <- deviance(fit)
     dev <- n * log(RSS/n)
     c(edf, dev + k * edf)
